@@ -4,7 +4,7 @@
  * Created Date: 27/05/2021
  * Author: Shun Suzuki
  * -----
- * Last Modified: 27/05/2021
+ * Last Modified: 05/06/2021
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
  * Copyright (c) 2021 Hapis Lab. All rights reserved.
@@ -12,7 +12,9 @@
  */
 
 mod sine;
+mod sine_pressure;
 mod r#static;
 
 pub use r#static::Static;
 pub use sine::Sine;
+pub use sine_pressure::SinePressure;
